<?php  
namespace Concrete\Package\LikesThisBlock\Block\LikesThis;

use Concrete\Core\Block\BlockController;
use Concrete\Core\Block\View\BlockView;
use User;
use Page;
use Database;
use Core;
use Redirect;

defined('C5_EXECUTE') or die(_("Access Denied."));

class Controller extends BlockController
{

    protected $btTable = 'btLikesThis';
    protected $btDefaultSet = 'social';

    /**
     * Used for localization. If we want to localize the name/description we have to include this
     */
    public function getBlockTypeDescription()
    {
        return t("Allows users to say they like a page");
    }

    public function getBlockTypeName()
    {
        return t("Like this Page");
    }

    public function view()
    {
        $this->requireAsset('css', 'core/font-awesome');
        $this->requireAsset('javascript', 'jquery');
        $this->requireAsset('core/lightbox');

        $u = new User();
        $page = Page::getCurrentPage();

        $this->set('page', $page);
        $this->set('u', $u);
        $this->set('count', $this->getLikeCount($page->getCollectionID()));
        $this->set('userLikesThis', $this->userLikesThis($u));
    }

    public function getLikesList($cID)
    {
        $db = Database::get();
        $a = $db->GetCol('select uID from btLikesThisUserPages where cID = ?', array($cID));
        return $a;
    }

    public function userLikesThis($u)
    {
        if (!$u->isRegistered()) {
            return false;
        }
        $db = Database::get();
        $page = Page::getCurrentPage();
        $cID = $page->getCollectionID();
        $uID = $u->getUserID();
        $hasMarked = $db->getOne("SELECT uID FROM btLikesThisUserPages WHERE uID = ? AND cID = ?", array($uID, $cID));
        return $hasMarked > 0;
    }

    public function action_like($token = false)
    {
        if (Core::make('helper/validation/token')->validate('like_page', $token)) {
            $page = Page::getCurrentPage();
            $u = new User();
            if ($u->isLoggedIn() && $u->getUserID() > 0) {
                $this->markLike($page->getCollectionID(), $page->getCollectionTypeID(), $u->getUserID());
            }
            if ($_SERVER['HTTP_X_REQUESTED_WITH'] == 'XMLHttpRequest') {
                $b = $this->getBlockObject();
                $bv = new BlockView($b);
                $bv->render('view');
            } else {
                Redirect::page($page)->send();
            }
        }

        exit;
    }

    public function markLike($cID, $ctID, $uID)
    {
        $db = Database::get();
        $has_marked = $db->getOne("SELECT uID FROM btLikesThisUserPages WHERE uID = ? AND cID = ?", array($uID, $cID));

        if ($has_marked <= 0) {
            $db->query("REPLACE INTO btLikesThisUserPages (cID, uID, ctID) VALUES (?,?,?)", array($cID, $uID, $ctID));
            $this->updateLikeCount($cID);
        }
    }


    protected function updateLikeCount($cID)
    {
        $res = $this->getLikeCount($cID);
        if (is_numeric($res)) {
            $page = Page::getByID($cID);
            $page->setAttribute('likes_this_page_count', $res);
        }
        return $res;
    }

    protected function getLikeCount($cID)
    {
        $db = Database::get();
        $res = $db->getOne("SELECT COUNT(cID) FROM btLikesThisUserPages WHERE cID = ?", array($cID));
        return $res;
    }

}

?>